# Tests

The tests in this repository are adaptations and modifications from the following open source projects:

- [Scanpy](https://github.com/scverse/scanpy)
- [AnnData](https://github.com/scverse/anndata)
- [Squidpy](https://github.com/scverse/squidpy)
- [Decoupler](https://github.com/saezlab/decoupler-py)

These tests have been adapted to fit specific needs and structures. Any errors or issues within are not attributed to the original projects.

For more information on individual test structures and licenses, please visit the respective projects' GitHub pages.
